@@ -23,23 +23,24 @@ my $myclass;
 
 BEGIN {
     $myclass = &{+sub {(caller(0))[0]}};
-    $VERSION = '0.75';
+    $VERSION = '0.77';
 }
 
 sub Version () { "$myclass v$VERSION" }
 
 use AutoLoader;
-use Exporter ();
+#use Exporter ();
 use Net::Gen 0.75 qw(:ALL);
 use Socket qw(!/^[a-z]/ /^inet_/);
 
 BEGIN {
-    @ISA = qw(Exporter Net::Gen);
+    @ISA = qw(Net::Gen);
 
 # Items to export into callers namespace by default
 # (move infrequently used names to @EXPORT_OK below)
     @EXPORT = qw(
 	INADDR_ALLHOSTS_GROUP
+	INADDR_ALLRTRS_GROUP
 	INADDR_ANY
 	INADDR_BROADCAST
 	INADDR_LOOPBACK
@@ -56,9 +57,11 @@ BEGIN {
 	IPPROTO_IDP
 	IPPROTO_IGMP
 	IPPROTO_IP
+	IPPROTO_IPIP
 	IPPROTO_MAX
 	IPPROTO_PUP
 	IPPROTO_RAW
+	IPPROTO_RSVP
 	IPPROTO_TCP
 	IPPROTO_TP
 	IPPROTO_UDP
@@ -73,9 +76,11 @@ BEGIN {
 
 # Other items we are prepared to export if requested
     @EXPORT_OK = qw(
+	DEFTTL
 	ICMP_ADVLENMIN
 	ICMP_ECHO
 	ICMP_ECHOREPLY
+	ICMP_INFOTYPE
 	ICMP_IREQ
 	ICMP_IREQREPLY
 	ICMP_MASKLEN
@@ -103,6 +108,8 @@ BEGIN {
 	ICMP_UNREACH_PORT
 	ICMP_UNREACH_PROTOCOL
 	ICMP_UNREACH_SRCFAIL
+	IN_BADCLASS
+	IN_CLASSA
 	IN_CLASSA_HOST
 	IN_CLASSA_MAX
 	IN_CLASSA_NET
@@ -110,6 +117,7 @@ BEGIN {
 	IN_CLASSA_SUBHOST
 	IN_CLASSA_SUBNET
 	IN_CLASSA_SUBNSHIFT
+	IN_CLASSB
 	IN_CLASSB_HOST
 	IN_CLASSB_MAX
 	IN_CLASSB_NET
@@ -117,26 +125,35 @@ BEGIN {
 	IN_CLASSB_SUBHOST
 	IN_CLASSB_SUBNET
 	IN_CLASSB_SUBNSHIFT
+	IN_CLASSC
 	IN_CLASSC_HOST
 	IN_CLASSC_MAX
 	IN_CLASSC_NET
 	IN_CLASSC_NSHIFT
+	IN_CLASSD
 	IN_CLASSD_HOST
 	IN_CLASSD_NET
 	IN_CLASSD_NSHIFT
+	IN_EXPERIMENTAL
 	IN_LOOPBACKNET
+	IN_MULTICAST
 	IPFRAGTTL
+	IPOPT_CIPSO
+	IPOPT_CLASS
 	IPOPT_CONTROL
+	IPOPT_COPIED
 	IPOPT_DEBMEAS
 	IPOPT_EOL
 	IPOPT_LSRR
 	IPOPT_MINOFF
 	IPOPT_NOP
+	IPOPT_NUMBER
 	IPOPT_OFFSET
 	IPOPT_OLEN
 	IPOPT_OPTVAL
 	IPOPT_RESERVED1
 	IPOPT_RESERVED2
+	IPOPT_RIPSO_AUX
 	IPOPT_RR
 	IPOPT_SATID
 	IPOPT_SECURITY
@@ -187,6 +204,8 @@ BEGIN {
 	IP_TOS
 	IP_TTL
 	MAXTTL
+	MAX_IPOPTLEN
+	MINTTL
 	SUBNETSHIFT
 	pack_sockaddr_in
 	unpack_sockaddr_in
@@ -200,7 +219,10 @@ BEGIN {
 			       IP_OPTIONS IP_RETOPTS)],
 	routines	=> [qw(pack_sockaddr_in unpack_sockaddr_in
 			       inet_ntoa inet_aton inet_addr
-			       htonl ntohl htons ntohs)],
+			       htonl ntohl htons ntohs
+			       ICMP_INFOTYPE IN_BADCLASS
+			       IN_EXPERIMENTAL IN_MULTICAST
+			       IPOPT_CLASS IPOPT_COPIED IPOPT_NUMBER)],
 	icmpvalues	=> [qw(ICMP_ADVLENMIN ICMP_ECHO ICMP_ECHOREPLY
 			       ICMP_IREQ ICMP_IREQREPLY ICMP_MASKLEN
 			       ICMP_MASKREPLY ICMP_MASKREQ ICMP_MAXTYPE
@@ -214,42 +236,61 @@ BEGIN {
 			       ICMP_UNREACH_NEEDFRAG ICMP_UNREACH_NET
 			       ICMP_UNREACH_PORT ICMP_UNREACH_PROTOCOL
 			       ICMP_UNREACH_SRCFAIL)],
-	ipoptions	=> [qw(IPOPT_CONTROL IPOPT_DEBMEAS IPOPT_EOL
-			       IPOPT_LSRR IPOPT_MINOFF IPOPT_NOP IPOPT_OFFSET
-			       IPOPT_OLEN IPOPT_OPTVAL
+	ipoptions	=> [qw(IPOPT_CIPSO IPOPT_CONTROL IPOPT_DEBMEAS
+			       IPOPT_EOL IPOPT_LSRR IPOPT_MINOFF IPOPT_NOP
+			       IPOPT_OFFSET IPOPT_OLEN IPOPT_OPTVAL
 			       IPOPT_RESERVED1 IPOPT_RESERVED2
-			       IPOPT_RR IPOPT_SATID
+			       IPOPT_RIPSO_AUX IPOPT_RR IPOPT_SATID
 			       IPOPT_SECURITY IPOPT_SECUR_CONFID
 			       IPOPT_SECUR_EFTO IPOPT_SECUR_MMMM
 			       IPOPT_SECUR_RESTR IPOPT_SECUR_SECRET
 			       IPOPT_SECUR_TOPSECRET IPOPT_SECUR_UNCLASS
 			       IPOPT_SSRR
 			       IPOPT_TS IPOPT_TS_PRESPEC
-			       IPOPT_TS_TSANDADDR IPOPT_TS_TSONLY)],
+			       IPOPT_TS_TSANDADDR IPOPT_TS_TSONLY
+			       MAX_IPOPTLEN)],
 	iptosvalues	=> [qw(IPTOS_LOWDELAY IPTOS_PREC_CRITIC_ECP
 			       IPTOS_PREC_FLASH IPTOS_PREC_FLASHOVERRIDE
 			       IPTOS_PREC_IMMEDIATE IPTOS_PREC_INTERNETCONTROL
 			       IPTOS_PREC_NETCONTROL IPTOS_PREC_PRIORITY
 			       IPTOS_PREC_ROUTINE IPTOS_RELIABILITY
 			       IPTOS_THROUGHPUT)],
-	protocolvalues	=> [qw(INADDR_ALLHOSTS_GROUP INADDR_ANY
-			       INADDR_BROADCAST INADDR_LOOPBACK
+	protocolvalues	=> [qw(DEFTTL
+			       INADDR_ALLHOSTS_GROUP INADDR_ALLRTRS_GROUP
+			       INADDR_ANY INADDR_BROADCAST INADDR_LOOPBACK
 			       INADDR_MAX_LOCAL_GROUP INADDR_NONE
 			       INADDR_UNSPEC_GROUP
-			       IP_DF IP_MAXPACKET IP_MF IP_MSS
+			       IN_LOOPBACKNET
 			       IPPORT_RESERVED IPPORT_USERRESERVED
 			       IPPROTO_EGP IPPROTO_EON IPPROTO_GGP
 			       IPPROTO_HELLO IPPROTO_ICMP IPPROTO_IDP
-			       IPPROTO_IGMP IPPROTO_IP IPPROTO_MAX
-			       IPPROTO_PUP IPPROTO_RAW IPPROTO_TCP IPPROTO_TP
+			       IPPROTO_IGMP IPPROTO_IP IPPROTO_IPIP
+			       IPPROTO_MAX IPPROTO_PUP IPPROTO_RAW
+			       IPPROTO_RSVP IPPROTO_TCP IPPROTO_TP
 			       IPPROTO_UDP
 			       IPFRAGTTL
-			       IPTTLDEC IPVERSION)],
+			       IPTTLDEC IPVERSION
+			       IP_DF IP_MAXPACKET IP_MF IP_MSS
+			       MAXTTL MAX_IPOPTLEN MINTTL)],
 	ipmulticast	=> [qw(IP_ADD_MEMBERSHIP IP_DEFAULT_MULTICAST_LOOP
 			       IP_DEFAULT_MULTICAST_TTL IP_DROP_MEMBERSHIP
 			       IP_MAX_MEMBERSHIPS IP_MULTICAST_IF
 			       IP_MULTICAST_LOOP IP_MULTICAST_TTL)],
+	deprecated	=> [qw(IN_CLASSA_HOST IN_CLASSA_MAX IN_CLASSA_NET
+			       IN_CLASSA_NSHIFT IN_CLASSA_SUBHOST
+			       IN_CLASSA_SUBNET IN_CLASSA_SUBNSHIFT
+			       IN_CLASSB_HOST IN_CLASSB_MAX IN_CLASSB_NET
+			       IN_CLASSB_NSHIFT IN_CLASSB_SUBHOST
+			       IN_CLASSB_SUBNET IN_CLASSB_SUBNSHIFT
+			       IN_CLASSC_HOST IN_CLASSC_MAX IN_CLASSC_NET
+			       IN_CLASSC_NSHIFT
+			       IN_CLASSD_HOST IN_CLASSD_NET IN_CLASSD_NSHIFT
+			       IN_CLASSA IN_CLASSB IN_CLASSC IN_CLASSD
+			       IPPORT_TIMESERVER
+			       SUBNETSHIFT)],
+	ALL		=> [@EXPORT, @EXPORT_OK],
     );
+
 }
 
 ;# sub AUTOLOAD inherited from Net::Gen
@@ -398,7 +439,7 @@ sub new				# $class, [\%params]
 	$self->registerParamKeys(\@Keys);
 	$self->registerParamHandlers(\%keyhandlers);
 	# register our socket options
-	$self->registerOptions('IPPROTO_IP', &IPPROTO_IP()+0, \%sockopts);
+	$self->registerOptions('IPPROTO_IP', IPPROTO_IP, \%sockopts);
 	# set our expected parameters
 	$self->setparams({PF => PF_INET, AF => AF_INET},-1);
 	$self = $self->init(@Args) if $class eq $myclass;
@@ -736,7 +777,7 @@ C<Net::UDP>.
 
 =head2 Public Methods
 
-=over 6
+=over
 
 =item new
 
@@ -859,13 +900,13 @@ updating more object parameters, it behaves the same as that in
 the base class.  The additional object parameters which get set
 are C<lcladdr>, C<lclhost>, C<lclport>, C<lclservice>,
 C<remaddr>, C<remhost>, C<remport>, and C<remservice>.  (They are
-described below.)
+described in L<"Known Object Parameters"> below.)
 
 =back
 
 =head2 Protected Methods
 
-[See the note in the C<Net::Gen> documentation about my
+[See the note in L<Net::Gen/"Protected Methods"> about my
 definition of protected methods in Perl.]
 
 None.
@@ -875,23 +916,14 @@ None.
 These are the socket options known to the C<Net::Inet> module
 itself:
 
-=over 6
+=over
 
 =item Z<>
 
-C<IP_HDRINCL>,
-C<IP_RECVDSTADDR>,
-C<IP_RECVOPTS>,
-C<IP_RECVRETOPTS>,
-C<IP_TOS>,
-C<IP_TTL>,
-C<IP_ADD_MEMBERSHIP>,
-C<IP_DROP_MEMBERSHIP>,
-C<IP_MULTICAST_IF>,
-C<IP_MULTICAST_LOOP>,
-C<IP_MULTICAST_TTL>,
-C<IP_OPTIONS>,
-C<IP_RETOPTS>
+C<IP_HDRINCL> C<IP_RECVDSTADDR> C<IP_RECVOPTS> C<IP_RECVRETOPTS>
+C<IP_TOS> C<IP_TTL> C<IP_ADD_MEMBERSHIP> C<IP_DROP_MEMBERSHIP>
+C<IP_MULTICAST_IF> C<IP_MULTICAST_LOOP> C<IP_MULTICAST_TTL>
+C<IP_OPTIONS> C<IP_RETOPTS>
 
 =back
 
@@ -900,7 +932,7 @@ C<IP_RETOPTS>
 These are the object parameters registered by the C<Net::Inet>
 module itself:
 
-=over 6
+=over
 
 =item IPproto
 
@@ -1044,7 +1076,7 @@ object parameter.
 
 =head2 Non-Method Subroutines
 
-=over 6
+=over
 
 =item inet_aton
 
@@ -1075,7 +1107,13 @@ provided (if possible), or C<undef> on error.  This used to be a
 separate implementation in this package, but is now inherited
 from the C<Socket> module.
 
-=item htonl/htons/ntohl/ntohs
+=item htonl
+
+=item htons
+
+=item ntohl
+
+=item ntohs
 
 As you'd expect, I think.
 
@@ -1106,182 +1144,149 @@ inverse of pack_sockaddr_in().  This differs from the
 implementation in the C<Socket> module in that the C<$family>
 value from the socket address is returned.
 
+=item INADDR_UNSPEC_GROUP
+
+=item INADDR_ALLHOSTS_GROUP
+
+=item INADDR_ALLRTRS_GROUP
+
+=item INADDR_MAX_LOCAL_GROUP
+
+Constant routines returning the F<unspecified local>, F<all hosts>,
+F<all routers>, or the maximum possible local IP multicast group
+address, respectively.  These routines return results in the form
+of a packed C<struct inaddr> much like C<INADDR_ANY> results
+described in L<Socket/INADDR_ANY>.
+
+=item IN_CLASSA
+
+=item IN_CLASSB
+
+=item IN_CLASSC
+
+=item IN_CLASSD
+
+=item IN_MULTICAST
+
+=item IN_EXPERIMENTAL
+
+=item IN_BADCLASS
+
+Usage:
+
+    $boolean = IN_EXPERIMENTAL(INADDR_ALLHOSTS_GROUP);
+    $boolean = IN_CLASSA(0x7f000001);
+
+These routines return the I<network class> information for the
+supplied IP address.  Of these, only IN_BADCLASS() and
+IN_MULTICAST() are really useful in today's Internet, since the
+advent of CIDR (classless Internet domain routing).  In
+particular, IN_EXPERIMENTAL() is at the mercy of your vendor's
+definition.  The first example above will be true only on older
+systems, which almost certainly don't support IP multicast
+anyway.  The argument to any of these functions can be either a
+packed C<struct inaddr> such as that returned by inet_ntoa() or
+unpack_sockaddr_in(), or an integer (or integer expression)
+giving an IP address in I<host> byte order.
+
+=item IPOPT_CLASS
+
+=item IPOPT_COPIED
+
+=item IPOPT_NUMBER
+
+Usage:
+
+    $optnum = IPOPT_NUMBER($option);
+
+These routines extract information from IP option numbers, as per
+the information on IP options in RFC 791.
+
+=item ...
+
+Other constants which relate to parts of IP or ICMP headers or
+vendor-defined socket options, as listed in L</"Exports"> below.
+
 =back
 
 =head2 Exports
 
-=over 6
+=over
 
 =item default
 
-C<INADDR_ALLHOSTS_GROUP>,
-C<INADDR_ANY>,
-C<INADDR_BROADCAST>,
-C<INADDR_LOOPBACK>,
-C<INADDR_MAX_LOCAL_GROUP>,
-C<INADDR_NONE>,
-C<INADDR_UNSPEC_GROUP>,
-C<IPPORT_RESERVED>,
-C<IPPORT_USERRESERVED>,
-C<IPPROTO_EGP>,
-C<IPPROTO_EON>,
-C<IPPROTO_GGP>,
-C<IPPROTO_HELLO>,
-C<IPPROTO_ICMP>,
-C<IPPROTO_IDP>,
-C<IPPROTO_IGMP>,
-C<IPPROTO_IP>,
-C<IPPROTO_MAX>,
-C<IPPROTO_PUP>,
-C<IPPROTO_RAW>,
-C<IPPROTO_TCP>,
-C<IPPROTO_TP>,
-C<IPPROTO_UDP>,
-C<htonl>,
-C<htons>,
-C<inet_addr>,
-C<inet_aton>,
-C<inet_ntoa>,
-C<ntohl>,
-C<ntohs>
+C<INADDR_ALLHOSTS_GROUP> C<INADDR_ALLRTRS_GROUP> C<INADDR_ANY>
+C<INADDR_BROADCAST> C<INADDR_LOOPBACK> C<INADDR_MAX_LOCAL_GROUP>
+C<INADDR_NONE> C<INADDR_UNSPEC_GROUP> C<IPPORT_RESERVED>
+C<IPPORT_USERRESERVED> C<IPPROTO_EGP> C<IPPROTO_EON> C<IPPROTO_GGP>
+C<IPPROTO_HELLO> C<IPPROTO_ICMP> C<IPPROTO_IDP> C<IPPROTO_IGMP>
+C<IPPROTO_IP> C<IPPROTO_IPIP> C<IPPROTO_MAX> C<IPPROTO_PUP>
+C<IPPROTO_RAW> C<IPPROTO_RSVP> C<IPPROTO_TCP> C<IPPROTO_TP>
+C<IPPROTO_UDP> C<htonl> C<htons> C<inet_addr> C<inet_aton> C<inet_ntoa>
+C<ntohl> C<ntohs>
 
 =item exportable
 
-C<ICMP_ADVLENMIN>,
-C<ICMP_ECHO>,
-C<ICMP_ECHOREPLY>,
-C<ICMP_IREQ>,
-C<ICMP_IREQREPLY>,
-C<ICMP_MASKLEN>,
-C<ICMP_MASKREPLY>,
-C<ICMP_MASKREQ>,
-C<ICMP_MAXTYPE>,
-C<ICMP_MINLEN>,
-C<ICMP_PARAMPROB>,
-C<ICMP_REDIRECT>,
-C<ICMP_REDIRECT_HOST>,
-C<ICMP_REDIRECT_NET>,
-C<ICMP_REDIRECT_TOSHOST>,
-C<ICMP_REDIRECT_TOSNET>,
-C<ICMP_SOURCEQUENCH>,
-C<ICMP_TIMXCEED>,
-C<ICMP_TIMXCEED_INTRANS>,
-C<ICMP_TIMXCEED_REASS>,
-C<ICMP_TSLEN>,
-C<ICMP_TSTAMP>,
-C<ICMP_TSTAMPREPLY>,
-C<ICMP_UNREACH>,
-C<ICMP_UNREACH_HOST>,
-C<ICMP_UNREACH_NEEDFRAG>,
-C<ICMP_UNREACH_NET>,
-C<ICMP_UNREACH_PORT>,
-C<ICMP_UNREACH_PROTOCOL>,
-C<ICMP_UNREACH_SRCFAIL>,
-C<IN_CLASSA_HOST>,
-C<IN_CLASSA_MAX>,
-C<IN_CLASSA_NET>,
-C<IN_CLASSA_NSHIFT>,
-C<IN_CLASSA_SUBHOST>,
-C<IN_CLASSA_SUBNET>,
-C<IN_CLASSA_SUBNSHIFT>,
-C<IN_CLASSB_HOST>,
-C<IN_CLASSB_MAX>,
-C<IN_CLASSB_NET>,
-C<IN_CLASSB_NSHIFT>,
-C<IN_CLASSB_SUBHOST>,
-C<IN_CLASSB_SUBNET>,
-C<IN_CLASSB_SUBNSHIFT>,
-C<IN_CLASSC_HOST>,
-C<IN_CLASSC_MAX>,
-C<IN_CLASSC_NET>,
-C<IN_CLASSC_NSHIFT>,
-C<IN_CLASSD_HOST>,
-C<IN_CLASSD_NET>,
-C<IN_CLASSD_NSHIFT>,
-C<IN_LOOPBACKNET>,
-C<IPFRAGTTL>,
-C<IPOPT_CONTROL>,
-C<IPOPT_DEBMEAS>,
-C<IPOPT_EOL>,
-C<IPOPT_LSRR>,
-C<IPOPT_MINOFF>,
-C<IPOPT_NOP>,
-C<IPOPT_OFFSET>,
-C<IPOPT_OLEN>,
-C<IPOPT_OPTVAL>,
-C<IPOPT_RESERVED1>,
-C<IPOPT_RESERVED2>,
-C<IPOPT_RR>,
-C<IPOPT_SATID>,
-C<IPOPT_SECURITY>,
-C<IPOPT_SECUR_CONFID>,
-C<IPOPT_SECUR_EFTO>,
-C<IPOPT_SECUR_MMMM>,
-C<IPOPT_SECUR_RESTR>,
-C<IPOPT_SECUR_SECRET>,
-C<IPOPT_SECUR_TOPSECRET>,
-C<IPOPT_SECUR_UNCLASS>,
-C<IPOPT_SSRR>,
-C<IPOPT_TS>,
-C<IPOPT_TS_PRESPEC>,
-C<IPOPT_TS_TSANDADDR>,
-C<IPOPT_TS_TSONLY>,
-C<IPPORT_TIMESERVER>,
-C<IPTOS_LOWDELAY>,
-C<IPTOS_PREC_CRITIC_ECP>,
-C<IPTOS_PREC_FLASH>,
-C<IPTOS_PREC_FLASHOVERRIDE>,
-C<IPTOS_PREC_IMMEDIATE>,
-C<IPTOS_PREC_INTERNETCONTROL>,
-C<IPTOS_PREC_NETCONTROL>,
-C<IPTOS_PREC_PRIORITY>,
-C<IPTOS_PREC_ROUTINE>,
-C<IPTOS_RELIABILITY>,
-C<IPTOS_THROUGHPUT>,
-C<IPTTLDEC>,
-C<IPVERSION>,
-C<IP_ADD_MEMBERSHIP>,
-C<IP_DEFAULT_MULTICAST_LOOP>,
-C<IP_DEFAULT_MULTICAST_TTL>,
-C<IP_DF>,
-C<IP_DROP_MEMBERSHIP>,
-C<IP_HDRINCL>,
-C<IP_MAXPACKET>,
-C<IP_MAX_MEMBERSHIPS>,
-C<IP_MF>,
-C<IP_MSS>,
-C<IP_MULTICAST_IF>,
-C<IP_MULTICAST_LOOP>,
-C<IP_MULTICAST_TTL>,
-C<IP_OPTIONS>,
-C<IP_RECVDSTADDR>,
-C<IP_RECVOPTS>,
-C<IP_RECVRETOPTS>,
-C<IP_RETOPTS>,
-C<IP_TOS>,
-C<IP_TTL>,
-C<MAXTTL>,
-C<SUBNETSHIFT>,
-C<pack_sockaddr_in>,
-C<unpack_sockaddr_in>
+C<DEFTTL> C<ICMP_ADVLENMIN> C<ICMP_ECHO> C<ICMP_ECHOREPLY>
+C<ICMP_INFOTYPE> C<ICMP_IREQ> C<ICMP_IREQREPLY> C<ICMP_MASKLEN>
+C<ICMP_MASKREPLY> C<ICMP_MASKREQ> C<ICMP_MAXTYPE> C<ICMP_MINLEN>
+C<ICMP_PARAMPROB> C<ICMP_REDIRECT> C<ICMP_REDIRECT_HOST>
+C<ICMP_REDIRECT_NET> C<ICMP_REDIRECT_TOSHOST> C<ICMP_REDIRECT_TOSNET>
+C<ICMP_SOURCEQUENCH> C<ICMP_TIMXCEED> C<ICMP_TIMXCEED_INTRANS>
+C<ICMP_TIMXCEED_REASS> C<ICMP_TSLEN> C<ICMP_TSTAMP> C<ICMP_TSTAMPREPLY>
+C<ICMP_UNREACH> C<ICMP_UNREACH_HOST> C<ICMP_UNREACH_NEEDFRAG>
+C<ICMP_UNREACH_NET> C<ICMP_UNREACH_PORT> C<ICMP_UNREACH_PROTOCOL>
+C<ICMP_UNREACH_SRCFAIL> C<IN_BADCLASS> C<IN_CLASSA> C<IN_CLASSA_HOST>
+C<IN_CLASSA_MAX> C<IN_CLASSA_NET> C<IN_CLASSA_NSHIFT>
+C<IN_CLASSA_SUBHOST> C<IN_CLASSA_SUBNET> C<IN_CLASSA_SUBNSHIFT>
+C<IN_CLASSB> C<IN_CLASSB_HOST> C<IN_CLASSB_MAX> C<IN_CLASSB_NET>
+C<IN_CLASSB_NSHIFT> C<IN_CLASSB_SUBHOST> C<IN_CLASSB_SUBNET>
+C<IN_CLASSB_SUBNSHIFT> C<IN_CLASSC> C<IN_CLASSC_HOST> C<IN_CLASSC_MAX>
+C<IN_CLASSC_NET> C<IN_CLASSC_NSHIFT> C<IN_CLASSD> C<IN_CLASSD_HOST>
+C<IN_CLASSD_NET> C<IN_CLASSD_NSHIFT> C<IN_EXPERIMENTAL>
+C<IN_LOOPBACKNET> C<IN_MULTICAST> C<IPFRAGTTL> C<IPOPT_CIPSO>
+C<IPOPT_CLASS> C<IPOPT_CONTROL> C<IPOPT_COPIED> C<IPOPT_DEBMEAS>
+C<IPOPT_EOL> C<IPOPT_LSRR> C<IPOPT_MINOFF> C<IPOPT_NOP> C<IPOPT_NUMBER>
+C<IPOPT_OFFSET> C<IPOPT_OLEN> C<IPOPT_OPTVAL> C<IPOPT_RESERVED1>
+C<IPOPT_RESERVED2> C<IPOPT_RIPSO_AUX> C<IPOPT_RR> C<IPOPT_SATID>
+C<IPOPT_SECURITY> C<IPOPT_SECUR_CONFID> C<IPOPT_SECUR_EFTO>
+C<IPOPT_SECUR_MMMM> C<IPOPT_SECUR_RESTR> C<IPOPT_SECUR_SECRET>
+C<IPOPT_SECUR_TOPSECRET> C<IPOPT_SECUR_UNCLASS> C<IPOPT_SSRR>
+C<IPOPT_TS> C<IPOPT_TS_PRESPEC> C<IPOPT_TS_TSANDADDR>
+C<IPOPT_TS_TSONLY> C<IPPORT_TIMESERVER> C<IPTOS_LOWDELAY>
+C<IPTOS_PREC_CRITIC_ECP> C<IPTOS_PREC_FLASH>
+C<IPTOS_PREC_FLASHOVERRIDE> C<IPTOS_PREC_IMMEDIATE>
+C<IPTOS_PREC_INTERNETCONTROL> C<IPTOS_PREC_NETCONTROL>
+C<IPTOS_PREC_PRIORITY> C<IPTOS_PREC_ROUTINE> C<IPTOS_RELIABILITY>
+C<IPTOS_THROUGHPUT> C<IPTTLDEC> C<IPVERSION> C<IP_ADD_MEMBERSHIP>
+C<IP_DEFAULT_MULTICAST_LOOP> C<IP_DEFAULT_MULTICAST_TTL> C<IP_DF>
+C<IP_DROP_MEMBERSHIP> C<IP_HDRINCL> C<IP_MAXPACKET>
+C<IP_MAX_MEMBERSHIPS> C<IP_MF> C<IP_MSS> C<IP_MULTICAST_IF>
+C<IP_MULTICAST_LOOP> C<IP_MULTICAST_TTL> C<IP_OPTIONS>
+C<IP_RECVDSTADDR> C<IP_RECVOPTS> C<IP_RECVRETOPTS> C<IP_RETOPTS>
+C<IP_TOS> C<IP_TTL> C<MAXTTL> C<MAX_IPOPTLEN> C<MINTTL> C<SUBNETSHIFT>
+C<pack_sockaddr_in> C<unpack_sockaddr_in>
 
 =item tags
 
 The following :tags are in C<%EXPORT_TAGS>, with the associated exportable
 values as listed:
 
-=over 4
+=over
 
 =item :sockopts
 
-C<IP_HDRINCL> C<IP_RECVDSTADDR> C<IP_RECVOPTS> C<IP_RECVRETOPTS> C<IP_TOS>
-C<IP_TTL> C<IP_ADD_MEMBERSHIP> C<IP_DROP_MEMBERSHIP> C<IP_MULTICAST_IF>
-C<IP_MULTICAST_LOOP> C<IP_MULTICAST_TTL> C<IP_OPTIONS> C<IP_RETOPTS>
+C<IP_HDRINCL> C<IP_RECVDSTADDR> C<IP_RECVOPTS> C<IP_RECVRETOPTS>
+C<IP_TOS> C<IP_TTL> C<IP_ADD_MEMBERSHIP> C<IP_DROP_MEMBERSHIP>
+C<IP_MULTICAST_IF> C<IP_MULTICAST_LOOP> C<IP_MULTICAST_TTL>
+C<IP_OPTIONS> C<IP_RETOPTS>
 
 =item :routines
 
 C<pack_sockaddr_in> C<unpack_sockaddr_in> C<inet_ntoa> C<inet_aton>
-C<inet_addr> C<htonl> C<ntohl> C<htons> C<ntohs>
+C<inet_addr> C<htonl> C<ntohl> C<htons> C<ntohs> C<ICMP_INFOTYPE>
+C<IN_BADCLASS> C<IN_EXPERIMENTAL> C<IN_MULTICAST> C<IPOPT_CLASS>
+C<IPOPT_COPIED> C<IPOPT_NUMBER>
 
 =item :icmpvalues
 
@@ -1290,20 +1295,21 @@ C<ICMP_IREQREPLY> C<ICMP_MASKLEN> C<ICMP_MASKREPLY> C<ICMP_MASKREQ>
 C<ICMP_MAXTYPE> C<ICMP_MINLEN> C<ICMP_PARAMPROB> C<ICMP_REDIRECT>
 C<ICMP_REDIRECT_HOST> C<ICMP_REDIRECT_NET> C<ICMP_REDIRECT_TOSHOST>
 C<ICMP_REDIRECT_TOSNET> C<ICMP_SOURCEQUENCH> C<ICMP_TIMXCEED>
-C<ICMP_TIMXCEED_INTRANS> C<ICMP_TIMXCEED_REASS> C<ICMP_TSLEN> C<ICMP_TSTAMP>
-C<ICMP_TSTAMPREPLY> C<ICMP_UNREACH> C<ICMP_UNREACH_HOST>
+C<ICMP_TIMXCEED_INTRANS> C<ICMP_TIMXCEED_REASS> C<ICMP_TSLEN>
+C<ICMP_TSTAMP> C<ICMP_TSTAMPREPLY> C<ICMP_UNREACH> C<ICMP_UNREACH_HOST>
 C<ICMP_UNREACH_NEEDFRAG> C<ICMP_UNREACH_NET> C<ICMP_UNREACH_PORT>
 C<ICMP_UNREACH_PROTOCOL> C<ICMP_UNREACH_SRCFAIL>
 
 =item :ipoptions
 
-C<IPOPT_CONTROL> C<IPOPT_DEBMEAS> C<IPOPT_EOL> C<IPOPT_LSRR> C<IPOPT_MINOFF>
-C<IPOPT_NOP> C<IPOPT_OFFSET> C<IPOPT_OLEN> C<IPOPT_OPTVAL> C<IPOPT_RESERVED1>
-C<IPOPT_RESERVED2> C<IPOPT_RR> C<IPOPT_SATID> C<IPOPT_SECURITY>
+C<IPOPT_CIPSO> C<IPOPT_CONTROL> C<IPOPT_DEBMEAS> C<IPOPT_EOL>
+C<IPOPT_LSRR> C<IPOPT_MINOFF> C<IPOPT_NOP> C<IPOPT_OFFSET>
+C<IPOPT_OLEN> C<IPOPT_OPTVAL> C<IPOPT_RESERVED1> C<IPOPT_RESERVED2>
+C<IPOPT_RIPSO_AUX> C<IPOPT_RR> C<IPOPT_SATID> C<IPOPT_SECURITY>
 C<IPOPT_SECUR_CONFID> C<IPOPT_SECUR_EFTO> C<IPOPT_SECUR_MMMM>
 C<IPOPT_SECUR_RESTR> C<IPOPT_SECUR_SECRET> C<IPOPT_SECUR_TOPSECRET>
 C<IPOPT_SECUR_UNCLASS> C<IPOPT_SSRR> C<IPOPT_TS> C<IPOPT_TS_PRESPEC>
-C<IPOPT_TS_TSANDADDR> C<IPOPT_TS_TSONLY>
+C<IPOPT_TS_TSANDADDR> C<IPOPT_TS_TSONLY> C<MAX_IPOPTLEN>
 
 =item :iptosvalues
 
@@ -1315,21 +1321,37 @@ C<IPTOS_THROUGHPUT>
 
 =item :protocolvalues
 
-C<INADDR_ALLHOSTS_GROUP> C<INADDR_ANY> C<INADDR_BROADCAST>
-C<INADDR_LOOPBACK> C<INADDR_MAX_LOCAL_GROUP> C<INADDR_NONE>
-C<INADDR_UNSPEC_GROUP> C<IP_DF> C<IP_MAXPACKET> C<IP_MF> C<IP_MSS>
-C<IPPORT_RESERVED> C<IPPORT_USERRESERVED> C<IPPROTO_EGP> C<IPPROTO_EON>
-C<IPPROTO_GGP> C<IPPROTO_HELLO> C<IPPROTO_ICMP> C<IPPROTO_IDP>
-C<IPPROTO_IGMP> C<IPPROTO_IP> C<IPPROTO_MAX> C<IPPROTO_PUP>
-C<IPPROTO_RAW> C<IPPROTO_TCP> C<IPPROTO_TP> C<IPPROTO_UDP> C<IPFRAGTTL>
-C<IPTTLDEC> C<IPVERSION>
+C<DEFTTL> C<INADDR_ALLHOSTS_GROUP> C<INADDR_ALLRTRS_GROUP>
+C<INADDR_ANY> C<INADDR_BROADCAST> C<INADDR_LOOPBACK>
+C<INADDR_MAX_LOCAL_GROUP> C<INADDR_NONE> C<INADDR_UNSPEC_GROUP>
+C<IN_LOOPBACKNET> C<IPPORT_RESERVED> C<IPPORT_USERRESERVED>
+C<IPPROTO_EGP> C<IPPROTO_EON> C<IPPROTO_GGP> C<IPPROTO_HELLO>
+C<IPPROTO_ICMP> C<IPPROTO_IDP> C<IPPROTO_IGMP> C<IPPROTO_IP>
+C<IPPROTO_IPIP> C<IPPROTO_MAX> C<IPPROTO_PUP> C<IPPROTO_RAW>
+C<IPPROTO_RSVP> C<IPPROTO_TCP> C<IPPROTO_TP> C<IPPROTO_UDP>
+C<IPFRAGTTL> C<IPTTLDEC> C<IPVERSION> C<IP_DF> C<IP_MAXPACKET> C<IP_MF>
+C<IP_MSS> C<MAXTTL> C<MAX_IPOPTLEN> C<MINTTL>
 
 =item :ipmulticast
 
 C<IP_ADD_MEMBERSHIP> C<IP_DEFAULT_MULTICAST_LOOP>
-C<IP_DEFAULT_MULTICAST_TTL> C<IP_DROP_MEMBERSHIP>
-C<IP_MAX_MEMBERSHIPS> C<IP_MULTICAST_IF> C<IP_MULTICAST_LOOP>
-C<IP_MULTICAST_TTL>
+C<IP_DEFAULT_MULTICAST_TTL> C<IP_DROP_MEMBERSHIP> C<IP_MAX_MEMBERSHIPS>
+C<IP_MULTICAST_IF> C<IP_MULTICAST_LOOP> C<IP_MULTICAST_TTL>
+
+=item :deprecated
+
+C<IN_CLASSA_HOST> C<IN_CLASSA_MAX> C<IN_CLASSA_NET> C<IN_CLASSA_NSHIFT>
+C<IN_CLASSA_SUBHOST> C<IN_CLASSA_SUBNET> C<IN_CLASSA_SUBNSHIFT>
+C<IN_CLASSB_HOST> C<IN_CLASSB_MAX> C<IN_CLASSB_NET> C<IN_CLASSB_NSHIFT>
+C<IN_CLASSB_SUBHOST> C<IN_CLASSB_SUBNET> C<IN_CLASSB_SUBNSHIFT>
+C<IN_CLASSC_HOST> C<IN_CLASSC_MAX> C<IN_CLASSC_NET> C<IN_CLASSC_NSHIFT>
+C<IN_CLASSD_HOST> C<IN_CLASSD_NET> C<IN_CLASSD_NSHIFT> C<IN_CLASSA>
+C<IN_CLASSB> C<IN_CLASSC> C<IN_CLASSD> C<IPPORT_TIMESERVER>
+C<SUBNETSHIFT>
+
+=item :ALL
+
+All of the above exportable items.
 
 =back
 
